Quantum XYZ
===========

<!-- [![DOI](https://zenodo.org/badge/598144740.svg)](https://zenodo.org/badge/latestdoi/598144740) -->
[![Gitpod Ready-to-Code](https://img.shields.io/badge/Gitpod-Ready--to--Code-blue?logo=gitpod)](https://gitpod.io/#https://github.com/Nozidoali/quantum-xyz.git)
[![CI](https://github.com/Nozidoali/quantum-xyz/actions/workflows/ci.yml/badge.svg)](https://github.com/Nozidoali/quantum-xyz/actions/workflows/ci.yml)


XYZ is a Python package for quantum compilation. It provides several implementations for quantum circuit optimizations, such as exact CNOT synthesis. [Read full documentation](https://quantum-xyz.readthedocs.io/en/latest/)

## Example

```sh
pip install quantum-xyz
cd example
python synthesize_dicke.py
```

